@@ -9,8 +9,8 @@
 #'   (if unspecified, all categorical dimensions are one-hot encoded) (integer
 #'   vector).
 #' @param verbose Display informational messages and the full list of
-#'   parameters and timers at the end of execution.  Default value "FALSE"
-#'   (logical).
+#'   parameters and timers at the end of execution.  Default value
+#'   "getOption("mlpack.verbose", FALSE)" (logical).
 #'
 #' @return A list with several components:
 #' \item{output}{Matrix to save one-hot encoded features data to (numeric
@@ -42,7 +42,7 @@
 #' }
 preprocess_one_hot_encoding <- function(input,
                                         dimensions=NA,
-                                        verbose=FALSE) {
+                                        verbose=getOption("mlpack.verbose", FALSE)) {
   # Create parameters and timers objects.
   p <- CreateParams("preprocess_one_hot_encoding")
   t <- CreateTimers()
@@ -58,10 +58,8 @@ preprocess_one_hot_encoding <- function(input,
     SetParamVecInt(p, "dimensions", dimensions)
   }
 
-  if (verbose) {
-    EnableVerbose()
-  } else {
-    DisableVerbose()
+  if (!identical(verbose, FALSE)) {
+    SetParamBool(p, "verbose", verbose)
   }
 
   # Mark all output options as passed.
